summaryrefslogtreecommitdiffstats
path: root/kresources/blogging/xmlrpcjob.h
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/blogging/xmlrpcjob.h')
-rw-r--r--kresources/blogging/xmlrpcjob.h54
1 files changed, 27 insertions, 27 deletions
diff --git a/kresources/blogging/xmlrpcjob.h b/kresources/blogging/xmlrpcjob.h
index cd657aa3b..7bb18b159 100644
--- a/kresources/blogging/xmlrpcjob.h
+++ b/kresources/blogging/xmlrpcjob.h
@@ -25,9 +25,9 @@
#include <kurl.h>
-#include <qstring.h>
-#include <qvaluelist.h>
-#include <qdom.h>
+#include <tqstring.h>
+#include <tqvaluelist.h>
+#include <tqdom.h>
#include <kio/jobclasses.h>
#include <kio/global.h>
@@ -59,42 +59,42 @@ Q_OBJECT
* Use KIO::xmlrpcPropFind(), KIO::xmlrpcPropPatch() and
* KIO::xmlrpcSearch() to create a new XmlrpcJob.
*/
- XmlrpcJob( const KURL& url, const QString& method,
- const QValueList<QVariant> &params, bool showProgressInfo );
+ XmlrpcJob( const KURL& url, const TQString& method,
+ const TQValueList<TQVariant> &params, bool showProgressInfo );
virtual ~XmlrpcJob();
/**
* Returns the response as a QDomDocument.
* @return the response document
*/
- QValueList<QVariant> &response() { return m_response; }
+ TQValueList<TQVariant> &response() { return m_response; }
/**
* Returns the type of the response.
* @return the type of the response
*/
XMLRPCResponseType responseType() const { return m_responseType; }
- static QString markupCall( const QString &cmd,
- const QValueList<QVariant> &args );
+ static TQString markupCall( const TQString &cmd,
+ const TQValueList<TQVariant> &args );
protected slots:
virtual void slotFinished();
- virtual void slotData( const QByteArray &data);
+ virtual void slotData( const TQByteArray &data);
protected:
- static QString marshal( const QVariant &arg );
- static QVariant demarshal( const QDomElement &e );
+ static TQString marshal( const TQVariant &arg );
+ static TQVariant demarshal( const TQDomElement &e );
- static bool isMessageResponse( const QDomDocument &doc );
- static bool isFaultResponse( const QDomDocument &doc );
+ static bool isMessageResponse( const TQDomDocument &doc );
+ static bool isFaultResponse( const TQDomDocument &doc );
- static XMLRPCResult parseMessageResponse( const QDomDocument &doc );
- static XMLRPCResult parseFaultResponse( const QDomDocument &doc );
+ static XMLRPCResult parseMessageResponse( const TQDomDocument &doc );
+ static XMLRPCResult parseFaultResponse( const TQDomDocument &doc );
private:
class XmlrpcJobPrivate;
XmlrpcJobPrivate *d;
- QString m_str_response;
- QValueList<QVariant> m_response;
+ TQString m_str_response;
+ TQValueList<TQVariant> m_response;
XMLRPCResponseType m_responseType;
};
@@ -103,21 +103,21 @@ Q_OBJECT
*
* @param url the URL of the XML-RPC Interface of the server
* @param method the name of the method to call
* @param params the arguments (as QValueList<QVariant>) for the method call.
* @param showProgressInfo true to show progress information
* @return the new XmlrpcJob
*/
-XmlrpcJob* xmlrpcCall( const KURL& url, const QString &method,
- const QValueList<QVariant> &params,
+XmlrpcJob* xmlrpcCall( const KURL& url, const TQString &method,
+ const TQValueList<TQVariant> &params,
bool showProgressInfo = true );
-XmlrpcJob* xmlrpcCall( const KURL& url, const QString &method,
- const QVariant &arg, bool showProgressInfo = true );
-XmlrpcJob* xmlrpcCall( const KURL& url, const QString &method,
- const QStringList &arg, bool showProgressInfo = true );
+XmlrpcJob* xmlrpcCall( const KURL& url, const TQString &method,
+ const TQVariant &arg, bool showProgressInfo = true );
+XmlrpcJob* xmlrpcCall( const KURL& url, const TQString &method,
+ const TQStringList &arg, bool showProgressInfo = true );
template <typename T>
-XmlrpcJob* xmlrpcCall( const KURL& url, const QString &method,
- const QValueList<T>&arg,bool showProgressInfo = true );
+XmlrpcJob* xmlrpcCall( const KURL& url, const TQString &method,
+ const TQValueList<T>&arg,bool showProgressInfo = true );
}
#endif
@@ -59,42 +59,42 @@ Q_OBJECT
virtual ~XmlrpcJob();
/**
- * Returns the response as a QDomDocument.
+ * Returns the response as a TQDomDocument.
* @return the response document
*/
@@ -103,21 +103,21 @@ Q_OBJECT
* @param url the URL of the XML-RPC Interface of the server
* @param method the name of the method to call
- * @param params the arguments (as QValueList<QVariant>) for the method call.
+ * @param params the arguments (as TQValueList<TQVariant>) for the method call.
* @param showProgressInfo true to show progress information
* @return the new XmlrpcJob